<?php
namespace OrganizationsManagement\Service;

use Doctrine\ORM\EntityManager;
use OrganizationsManagement\Util\InstanceProvider;
use OrganizationsManagement\Repository\CadastroAssunto as CadastroAssuntoRepository;

class CadastroAssunto {
    /**
     * @var EntityManager
     */
    private $entityManager;
    /**
     * @var CadastroAssuntoRepository
     */
    private $cadastroAssuntoRepository;

    /**
     * Classification constructor.
     * @param EntityManager $entityManager
     * @param CadastroAssuntoRepository $cadastroAssuntoRepository
     */
    public function __construct(EntityManager $entityManager, CadastroAssuntoRepository $cadastroAssuntoRepository)
    {
        $this->entityManager = $entityManager;
        $this->cadastroAssuntoRepository = $cadastroAssuntoRepository;
    }

    public function findTreeGridSubject($parametros)
    {
        $fetchOnDemand = '';
        if (isset($parametros["PAI_ID"]) && ($parametros["PAI_ID"]) != 'NULL' ) {
            $fetchOnDemand = " AND OQA.PAI_ID = '" . $parametros["PAI_ID"] . "'";
        }

        $fetchOnDemandPrimeiraLinha = '';
        if (isset($parametros["PAI_ID"]) && $parametros["PAI_ID"] == 'NULL') {
            $fetchOnDemandPrimeiraLinha = " AND OQA.PAI_ID IS NULL";
        }

        return $this->cadastroAssuntoRepository->findTreeGridSubject($fetchOnDemand, $fetchOnDemandPrimeiraLinha);
    }

    public function saveModalCadAssuntoAdd($dsassunto, $paiId, $id)
    {
        $connection = $this->entityManager->getConnection();
        $connection->beginTransaction();
        try{
            if ($id == null) {
                $treesubjectproduct = InstanceProvider::getFactory()->getCadAssunto()->create($dsassunto, $paiId);
                $this->entityManager->persist($treesubjectproduct);
                $this->entityManager->flush();
            } else {
                $treesubjectproductRepository = InstanceProvider::getRepository()->getOmOqaAssunto()->findOneBy(array('id' => $id));
                $treesubjectproduct = InstanceProvider::getFactory()->getCadAssunto()->update($treesubjectproductRepository, $dsassunto, $paiId, $id);
                $this->entityManager->persist($treesubjectproduct);
                $this->entityManager->flush();
            }
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw $e;
        }
    }

    public function removeSubject($id)
    {   
        $connection = $this->entityManager->getConnection();
        $connection->beginTransaction();
        try{
            $this->removeFilhoRecursivo($id);
            $treesubjectproductRepository = InstanceProvider::getRepository()->getOmOqaAssunto()->findOneBy(array('id' => $id));
            $this->entityManager->remove($treesubjectproductRepository);
            $this->entityManager->flush();
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw $e;
        }
    }

    public function removeFilhoRecursivo($id) {
        $treesubjectproductRepository = InstanceProvider::getRepository()->getOmOqaAssunto()->findBy(array('paiId' => $id));
        foreach ($treesubjectproductRepository as $filho) {
            $this->removeFilhoRecursivo($filho->getId());
            $this->entityManager->remove($filho);
            $this->entityManager->flush();
        }
    }
}
