import Vue from 'vue';
import Store from '../store';

let gridResizeTimout = 0;

const ScreenService = {
    showLoader: () => {
        Store.commit('ScreenService/SET_LOAD', true);
    },
    hideLoader: () => {
        Store.commit('ScreenService/SET_LOAD', false);
    },
    notification: (text: string, color: string) => {
        let isVisible = true;
        Store.dispatch('ScreenService/setNotification', { isVisible, text, color });
        isVisible = false;
        setTimeout(() => {
            Store.dispatch('ScreenService/setNotification', { isVisible });
        }, 3000);
    },
    showMessage(title: any, text: any, icon: any) {
        Vue.swal({
            title,
            text,
            icon,
        });
    },
    showMessageSuccess(text: any) {
        Vue.swal({
            title: 'Sucesso!',
            text,
            icon: 'success',
        });
    },
    showMessageInfo(text: any) {
        Vue.swal({
            title: 'Informação!',
            text,
            icon: 'info',
        });
    },
    showMessageWarning(text: any) {
        Vue.swal({
            title: 'Atenção!',
            text,
            icon: 'warning',
        });
    },
    showMessageError(text: any) {
        Vue.swal({
            title: 'Error!',
            text,
            icon: 'error',
        });
    },
    confirmMessage(text: string) {
        return new Promise((resolve) => {
            Vue.swal({
                icon: 'question',
                title: '',
                text,
                showCancelButton: true,
                cancelButtonText: 'Não',
                cancelButtonColor: '#ff5252',
                confirmButtonText: 'Sim',
            }).then((response) => {
                if (response.isConfirmed) {
                    resolve(true);
                }
                resolve(false);
            });
        });
    },
    createAndStartResizeObservable(value: number) {
        window.addEventListener('resize', this.resizeTekGrid.bind(this, value));
        this.resizeTekGrid(value);
    },
    resizeTekGrid(value: number) {
        clearTimeout(gridResizeTimout);
        gridResizeTimout = window.setTimeout(() => {
            const heightValue = window.innerHeight - value;
            const docGridId = document.getElementsByClassName('v-data-table__wrapper') as HTMLCollectionOf<HTMLElement>;
            docGridId[0].style.height = `${heightValue}px`;
        }, 100);
    },
    destroyResizeObservable(value: number) {
        window.removeEventListener('resize', this.resizeTekGrid.bind(this, value));
    },
};

Vue.prototype.$screenService = ScreenService;
export default ScreenService;
